/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-07-16 17:48:37.
 * *************************************************
 */

package cn.com.qmth.examcloud.app.service;

import cn.com.qmth.examcloud.app.model.Constants;
import cn.com.qmth.examcloud.app.model.ResBody;
import cn.com.qmth.examcloud.app.model.Result;
import cn.com.qmth.examcloud.app.utils.HttpBuilder;
import cn.com.qmth.examcloud.app.utils.HttpUtils;
import cn.com.qmth.examcloud.app.utils.JsonMapper;
import okhttp3.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

import static cn.com.qmth.examcloud.app.model.Constants.*;

/**
 * 认证中心业务服务接口
 */
@Service
public class UserAuthService {
    private static Logger log = LoggerFactory.getLogger(UserAuthService.class);
    @Autowired
    private PropertyService propertyService;

    public Result login(String account, String password, Long rootOrgId) throws Exception {
        //封装请求参数
        final String requestUrl = String.format("%s/api/ecs_core/auth/login", propertyService.getUserAuthUrl());
        Map<String, String> params = new HashMap<>();
        params.put("accountValue", account);
        params.put("password", password);
        params.put("rootOrgId", String.valueOf(rootOrgId));
        params.put("accountType", DEFAULT_ACCOUNT_TYPE);
        params.put("domain", "");
        String json = new JsonMapper().toJson(params);
        RequestBody formBody = FormBody.create(MediaType.parse(Constants.CHARSET_JSON_UTF8), json);
        Request request = new Request.Builder()
                .url(requestUrl)
                .post(formBody)
                .build();
        //执行请求
        Response response = HttpBuilder.client.getInstance().newCall(request).execute();
        String bodyStr = response.body().string();
        if (response.isSuccessful()) {
            return new Result().success(bodyStr);
        } else {
            log.warn("Http response is " + bodyStr);
            ResBody body = new JsonMapper().fromJson(bodyStr, ResBody.class);
            if (body != null && body.getCode() != null) {
                return new Result().error(body.getDesc());
            }
            return new Result().error(bodyStr);
        }
    }

    public Result logout(String key, String token) throws Exception {
        //封装请求参数
        final String requestUrl = String.format("%s/api/ecs_core/auth/logout", propertyService.getUserAuthUrl());
        RequestBody formBody = new FormBody.Builder()
                .add(PARAM_KEY, key)
                .add(PARAM_TOKEN, token)
                .build();
        return HttpUtils.doPost(requestUrl, formBody, key, token);
    }

    public Result getUserInfo(String key, String token) throws Exception {
        //封装请求参数
        final String requestUrl = String.format("%s/api/ecs_core/auth/getLoginUser", propertyService.getUserAuthUrl());
        RequestBody formBody = new FormBody.Builder()
                .add(PARAM_KEY, key)
                .add(PARAM_TOKEN, token)
                .build();
        return HttpUtils.doPost(requestUrl, formBody, key, token);
    }

    public Result updatePassword(String key, String token, Long userId, String password) throws Exception {
        //封装请求参数
        final String requestUrl = String.format("%s/api/ecs_core/user/password", propertyService.getUserAuthUrl());
        RequestBody formBody = new FormBody.Builder()
                .add("userId", String.valueOf(userId))
                .add("password", password)
                .build();
        return HttpUtils.doPut(requestUrl, formBody, key, token);
    }

}